@@ -7,7 +7,9 @@ module Retryable
       :matching,
       :on,
       :sleep,
-      :tries
+      :tries,
+      :not,
+      :sleep_method
     ].freeze
 
     attr_accessor :ensure
@@ -16,6 +18,8 @@ module Retryable
     attr_accessor :on
     attr_accessor :sleep
     attr_accessor :tries
+    attr_accessor :not
+    attr_accessor :sleep_method
 
     attr_accessor :enabled
 
@@ -28,7 +32,8 @@ module Retryable
       @on           = StandardError
       @sleep        = 1
       @tries        = 2
-
+      @not          = []
+      @sleep_method = lambda do |seconds| Kernel.sleep(seconds) end
       @enabled     = true
     end
 
